import service from "../service";
import Qs from 'qs';

// 保存本地模型
export const saveLocalModel = (data) => {
  return service({
    url: `${data.repo}/modelmanage/create_local_model`,
    method: 'post',
    headers: { 'Content-type': 'application/x-www-form-urlencoded' },
    params: {},
    data: Qs.stringify(data),
  });
};

// 修改模型
// data: {id,type,name,version,engine,label,description:}
export const modifyModel = (data) => {
  return service({
    url: `${data.repo}/modelmanage/modify_model`,
    method: 'put',
    headers: { 'Content-type': 'application/x-www-form-urlencoded' },
    params: {},
    data: Qs.stringify(data),
  });
};

export const modifyModelStatus = (data) => {
  return service({
    url: `${data.repo}/modelmanage/modify_model_status`,
    method: 'put',
    headers: { 'Content-type': 'application/x-www-form-urlencoded' },
    params: {},
    data: Qs.stringify(data),
  });
};

// 求模型信息
export const getModelInfoByName = (params) => {
  return service({
    url: `${params.repo}/modelmanage/show_model_info_api`,
    method: 'get',
    params,
    data: {},
  });
};

// 求模型中文件列表
// params {repo, ID, parentDir}
export const getModelFiles = (params) => {
  return service({
    url: `${params.repo}/modelmanage/query_onelevel_modelfile`,
    method: 'get',
    params,
    data: {},
  });
};

// 删除模型文件
// params {repo, id, fileName}
export const deleteModelFile = (params) => {
  return service({
    url: `${params.repo}/modelmanage/delete_model_file`,
    method: 'delete',
    params,
    data: {},
  });
};

/* 文件上传相关 */
// 上传文件1: 获取文件chunks信息
// params: { md5, type: 0-CPU/GPU,1-NPU, file_name, scene: 'model', modeluuid }
// return: uploadID, uuid, uploaded, chunks, attachID, modeluuid, modelName, fileName
export const getChunks = (params) => {
  return service({
    url: `/attachments/model/get_chunks`,
    method: 'get',
    params,
    data: {},
  });
};

// 上传文件2: 上传新文件
// params: { totalChunkCounts, md5, size, fileType, type, file_name, scene=model, modeluuid=xxxx }
// return: uploadID, uuid
export const getNewMultipart = (params) => {
  return service({
    url: `/attachments/model/new_multipart`,
    method: 'get',
    params,
    data: {},
  });
};

// 上传文件3: 获取分片上传地址
// params: { uuid, uploadID, size, chunkNumber, type, file_name, scene=model }
// return: url
export const getMultipartUrl = (params) => {
  return service({
    url: `/attachments/model/get_multipart_url`,
    method: 'get',
    params,
    data: {},
  });
};

// 上传文件4: 完成上传后
// data: { uuid, uploadID, size, type, file_name, dataset_id, description, scene=model, modeluuid=xxxx }
export const setCompleteMultipart = (data) => {
  return service({
    url: `/attachments/model/complete_multipart`,
    method: 'post',
    headers: { 'Content-type': 'application/x-www-form-urlencoded' },
    params: {},
    data: Qs.stringify(data),
  });
};
